Open a dataset
- mention collections

Info Button

Color by meta

Color by gene
- mention recent genes
- mention quickgenes

How specific is a marker:
Heatmap 

Show two annotations:
Split mode

Change Layout

Rename cluster (share URL)

Select cells and modify selections

Select with rectangle

Edit > Find Cells

Export identifiers or search by ID

Show quickgenes change color
- meta histogram

Custom annotations
